aboutsummaryrefslogtreecommitdiffstats
path: root/catalog-be/src/main/resources/scripts/import/tosca/upgradeNormative.py
diff options
context:
space:
mode:
Diffstat (limited to 'catalog-be/src/main/resources/scripts/import/tosca/upgradeNormative.py')
-rw-r--r--catalog-be/src/main/resources/scripts/import/tosca/upgradeNormative.py51
1 files changed, 27 insertions, 24 deletions
diff --git a/catalog-be/src/main/resources/scripts/import/tosca/upgradeNormative.py b/catalog-be/src/main/resources/scripts/import/tosca/upgradeNormative.py
index 69a51f41f1..573e05b46a 100644
--- a/catalog-be/src/main/resources/scripts/import/tosca/upgradeNormative.py
+++ b/catalog-be/src/main/resources/scripts/import/tosca/upgradeNormative.py
@@ -17,21 +17,21 @@ from importOnapTypes import importOnapTypes
from importCommon import *
import importCommon
#################################################################################################################################################################################################
# #
# Upgrades the normative types #
# #
# activation : #
# python upgradeNormative.py [-i <be host> | --ip=<be host>] [-p <be port> | --port=<be port> ] [-u <user userId> | --user=<user userId> ] [-d <true|false> | --debug=<true|false>] #
# #
# #
# shortest activation (be host = localhost, be port = 8080, user = jh0003): # # #
# python upgradeNormative.py #
# #
#################################################################################################################################################################################################
def usage():
- print sys.argv[0], '[-i <be host> | --ip=<be host>] [-p <be port> | --port=<be port> ] [-u <user userId> | --user=<user userId> ] [-d <true|false> | --debug=<true|false>]'
+ print sys.argv[0], '[optional -s <scheme> | --scheme=<scheme>, default http] [-i <be host> | --ip=<be host>] [-p <be port> | --port=<be port> ] [-u <user userId> | --user=<user userId> ] [-d <true|false> | --debug=<true|false>]'
def handleResults(results, updateversion):
printFrameLine()
@@ -52,9 +52,10 @@ def main(argv):
debugf = None
updateversion = 'true'
importCommon.debugFlag = False
+ scheme = 'http'
try:
- opts, args = getopt.getopt(argv,"i:p:u:d:h",["ip=","port=","user=","debug="])
+ opts, args = getopt.getopt(argv,"i:p:u:d:h:s:",["ip=","port=","user=","debug=","scheme="])
except getopt.GetoptError:
usage()
errorAndExit(2, 'Invalid input')
@@ -70,11 +71,13 @@ def main(argv):
bePort = arg
elif opt in ("-u", "--user"):
adminUser = arg
+ elif opt in ("-s", "--scheme"):
+ scheme = arg
elif opt in ("-d", "--debug"):
print arg
debugf = bool(arg.lower() == "true" or arg.lower() == "yes")
- print 'be host =',beHost,', be port =', bePort,', user =', adminUser, ', debug =', debugf
+ print 'scheme =',scheme,', be host =',beHost,', be port =', bePort,', user =', adminUser, ', debug =', debugf
if (debugf != None):
print 'set debug mode to ' + str(debugf)
@@ -91,27 +94,27 @@ def main(argv):
baseFileLocation = pathdir + "/../../../import/tosca/"
fileLocation = baseFileLocation + "categories/"
- importCategories(beHost, bePort, adminUser, False, fileLocation)
+ importCategories(scheme, beHost, bePort, adminUser, False, fileLocation)
fileLocation = baseFileLocation + "data-types/"
- importDataTypes(beHost, bePort, adminUser, False, fileLocation)
+ importDataTypes(scheme, beHost, bePort, adminUser, False, fileLocation)
fileLocation = baseFileLocation + "policy-types/"
- importPolicyTypes(beHost, bePort, adminUser, False, fileLocation)
-
- fileLocation = baseFileLocation + "group-types/"
- importGroupTypes(beHost, bePort, adminUser, False, fileLocation)
+ importPolicyTypes(scheme, beHost, bePort, adminUser, False, fileLocation)
fileLocation = baseFileLocation + "capability-types/"
- importNormativeCapabilities(beHost, bePort, adminUser, False, fileLocation)
+ importNormativeCapabilities(scheme, beHost, bePort, adminUser, False, fileLocation)
+
+ fileLocation = baseFileLocation + "group-types/"
+ importGroupTypes(scheme, beHost, bePort, adminUser, False, fileLocation)
fileLocation = baseFileLocation + "interface-lifecycle-types/"
- importNormativeInterfaceLifecycleType(beHost, bePort, adminUser, False, fileLocation)
+ importNormativeInterfaceLifecycleType(scheme, beHost, bePort, adminUser, False, fileLocation)
print 'sleep until data type cache is updated'
time.sleep( 70 )
- resultsHeat = upgradeTypesPerConfigFile(beHost, bePort, adminUser, baseFileLocation, updateversion)
+ resultsHeat = upgradeTypesPerConfigFile(scheme, beHost, bePort, adminUser, baseFileLocation, updateversion)
handleResults(resultsHeat, 'false')
errorAndExit(0, None)
@@ -17,21 +17,21 @@ from importOnapTypes import importOnapTypes
from importCommon import *
import importCommon
-#################################################################################################################################################################################################
-# #
-# Upgrades the normative types #
-# #
-# activation : #
-# python upgradeNormative.py [-i <be host> | --ip=<be host>] [-p <be port> | --port=<be port> ] [-u <user userId> | --user=<user userId> ] [-d <true|false> | --debug=<true|false>] #
-# #
-# #
-# shortest activation (be host = localhost, be port = 8080, user = jh0003): # # #
-# python upgradeNormative.py #
-# #
-#################################################################################################################################################################################################
+#################################################################################################################################################################################################################################
+# #
+# Upgrades the normative types #
+# #
+# activation : #
+# python upgradeNormative.py [-s <scheme> | --scheme=<scheme> ] [-i <be host> | --ip=<be host>] [-p <be port> | --port=<be port> ] [-u <user userId> | --user=<user userId> ] [-d <true|false> | --debug=<true|false>] #
+# #
+# #
+# shortest activation (be host = localhost, be port = 8080, user = jh0003): #
+# python upgradeNormative.py #
+# #
+#################################################################################################################################################################################################################################
def usage():